@@ -26,11 +26,11 @@ sub import {
     return;
 }
 
-die "Perl lib version (v5.8.4) doesn't match executable version ($])"
+die "Perl lib version (v5.8.6) doesn't match executable version ($])"
     unless $^V;
 
-$^V eq v5.8.4
-    or die "Perl lib version (v5.8.4) doesn't match executable version (" .
+$^V eq v5.8.6
+    or die "Perl lib version (v5.8.6) doesn't match executable version (" .
 	sprintf("v%vd",$^V) . ")";
 
 ##
@@ -42,9 +42,9 @@ $^V eq v5.8.4
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Wed May 26 11:49:10 PDT 2004
+## Configuration time: Sat Jan  1 19:32:19 PST 2005
 ## Configured by     : root
-## Target system     : linux midas 2.4.26 #6 wed apr 14 16:31:11 pdt 2004 i686 unknown unknown gnulinux 
+## Target system     : linux midas 2.4.28 #6 tue dec 14 14:41:15 pst 2004 i686 unknown unknown gnulinux 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -81,6 +81,10 @@ Summary of my $package (revision $revision $version_patchlevel_string) configura
     cccdlflags='$cccdlflags', lddlflags='$lddlflags'
 
 !END!
+my $i = 0;
+foreach my $c (4,3,2) { $i |= ord($c); $i <<= 8 }
+$i |= ord(1);
+my $byteorder = join('', unpack('aaaa', pack('L!', $i)));
 my $summary_expanded;
 
 sub myconfig {
@@ -90,22 +94,23 @@ sub myconfig {
     $summary_expanded;
 }
 
-our $Config_SH : unique = <<'!END!';
-archlibexp='/usr/lib/perl5/5.8.4/i486-linux'
+local *_ = \my $a;
+$_ = <<'!END!';
+archlibexp='/usr/lib/perl5/5.8.6/i486-linux'
 archname='i486-linux'
 cc='cc'
-ccflags='-fno-strict-aliasing -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
-cppflags='-fno-strict-aliasing -I/usr/local/include'
+ccflags='-fno-strict-aliasing -pipe -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
+cppflags='-fno-strict-aliasing -pipe -I/usr/local/include'
 dlsrc='dl_dlopen.xs'
 dynamic_ext='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
-installarchlib='/usr/lib/perl5/5.8.4/i486-linux'
-installprivlib='/usr/lib/perl5/5.8.4'
+installarchlib='/usr/lib/perl5/5.8.6/i486-linux'
+installprivlib='/usr/lib/perl5/5.8.6'
 libpth='/usr/local/lib /lib /usr/lib'
 libs='-lnsl -lgdbm -ldb -ldl -lm -lcrypt -lutil -lc'
 osname='linux'
-osvers='2.4.26'
+osvers='2.4.28'
 prefix='/usr'
-privlibexp='/usr/lib/perl5/5.8.4'
+privlibexp='/usr/lib/perl5/5.8.6'
 sharpbang='#!'
 shsharp='true'
 so='so'
@@ -125,11 +130,11 @@ PERL_API_SUBVERSION='0'
 PERL_API_VERSION='8'
 PERL_CONFIG_SH='true'
 PERL_REVISION='5'
-PERL_SUBVERSION='4'
+PERL_SUBVERSION='6'
 PERL_VERSION='8'
 RCSfile='$RCSfile'
 Revision='$Revision'
-SUBVERSION='4'
+SUBVERSION='6'
 Source=''
 State=''
 _a='.a'
@@ -145,7 +150,7 @@ api_subversion='0'
 api_version='8'
 api_versionstring='5.8.0'
 ar='ar'
-archlib='/usr/lib/perl5/5.8.4/i486-linux'
+archlib='/usr/lib/perl5/5.8.6/i486-linux'
 archname64=''
 archobjs=''
 asctime_r_proto='0'
@@ -164,11 +169,11 @@ cccdlflags='-fPIC'
 ccdlflags='-Wl,-E'
 ccflags_uselargefiles='-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
 ccname='gcc'
-ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=3'
+ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=4'
 ccversion=''
 cf_by='root'
 cf_email='root@midas.slackware.lan'
-cf_time='Wed May 26 11:49:10 PDT 2004'
+cf_time='Sat Jan  1 19:32:19 PST 2005'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -182,10 +187,10 @@ config_arg2='-Dprefix=/usr'
 config_arg3='-Dcccdlflags=-fPIC'
 config_arg4='-Dinstallprefix=/usr'
 config_arg5='-Doptimize=-O2 -march=i486 -mcpu=i686'
-config_arg6='-Dinc_version_list=5.8.3 5.8.2 5.8.1 5.8.0'
+config_arg6='-Dinc_version_list=5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0'
 config_arg7='-Darchname=i486-linux'
 config_argc='7'
-config_args='-de -Dprefix=/usr -Dcccdlflags=-fPIC -Dinstallprefix=/usr -Doptimize=-O2 -march=i486 -mcpu=i686 -Dinc_version_list=5.8.3 5.8.2 5.8.1 5.8.0 -Darchname=i486-linux'
+config_args='-de -Dprefix=/usr -Dcccdlflags=-fPIC -Dinstallprefix=/usr -Doptimize=-O2 -march=i486 -mcpu=i686 -Dinc_version_list=5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0 -Darchname=i486-linux'
 contains='grep'
 cp='cp'
 cpio=''
@@ -644,7 +649,7 @@ full_csh='/bin/csh'
 full_sed='/usr/bin/sed'
 gccansipedantic=''
 gccosandvers=''
-gccversion='3.3.3'
+gccversion='3.3.4'
 getgrent_r_proto='0'
 getgrgid_r_proto='0'
 getgrnam_r_proto='0'
@@ -672,7 +677,7 @@ gidtype='gid_t'
 glibpth='/usr/shlib  /lib /usr/lib /usr/lib/386 /lib/386 /usr/ccs/lib /usr/ucblib /usr/local/lib '
 gmake='gmake'
 gmtime_r_proto='0'
-gnulibc_version='2.3.2'
+gnulibc_version='2.3.3'
 grep='grep'
 groupcat='cat /etc/group'
 groupstype='gid_t'
@@ -776,8 +781,8 @@ i_varargs='undef'
 i_varhdr='stdarg.h'
 i_vfork='undef'
 ignore_versioned_solibs='y'
-inc_version_list='5.8.3 5.8.2 5.8.1 5.8.0'
-inc_version_list_init='"5.8.3","5.8.2","5.8.1","5.8.0",0'
+inc_version_list='5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0'
+inc_version_list_init='"5.8.5","5.8.4","5.8.3","5.8.2","5.8.1","5.8.0",0'
 incpath=''
 inews=''
 installbin='/usr/bin'
@@ -788,11 +793,11 @@ installman3dir='/usr/share/man/man3'
 installprefix='/usr'
 installprefixexp='/usr'
 installscript='/usr/bin'
-installsitearch='/usr/lib/perl5/site_perl/5.8.4/i486-linux'
+installsitearch='/usr/lib/perl5/site_perl/5.8.6/i486-linux'
 installsitebin='/usr/bin'
 installsitehtml1dir=''
 installsitehtml3dir=''
-installsitelib='/usr/lib/perl5/site_perl/5.8.4'
+installsitelib='/usr/lib/perl5/site_perl/5.8.6'
 installsiteman1dir='/usr/share/man/man1'
 installsiteman3dir='/usr/share/man/man3'
 installsitescript='/usr/bin'
@@ -820,7 +825,7 @@ ldflags_uselargefiles=''
 ldlibpthname='LD_LIBRARY_PATH'
 less='less'
 lib_ext='.a'
-libc='/lib/libc-2.3.2.so'
+libc='/lib/libc-2.3.3.so'
 libperl='libperl.a'
 libsdirs=' /usr/lib'
 libsfiles=' libnsl.so libgdbm.so libdb.so libdl.so libm.so libcrypt.so libutil.so libc.so'
@@ -868,7 +873,7 @@ mv=''
 myarchname='i686-linux'
 mydomain='.slackware.lan'
 myhostname='midas'
-myuname='linux midas 2.4.26 #6 wed apr 14 16:31:11 pdt 2004 i686 unknown unknown gnulinux '
+myuname='linux midas 2.4.28 #6 tue dec 14 14:41:15 pst 2004 i686 unknown unknown gnulinux '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -913,7 +918,7 @@ plibpth=''
 pmake=''
 pr=''
 prefixexp='/usr'
-privlib='/usr/lib/perl5/5.8.4'
+privlib='/usr/lib/perl5/5.8.6'
 procselfexe='"/proc/self/exe"'
 prototype='define'
 ptrsize='4'
@@ -965,24 +970,24 @@ shar=''
 shmattype='void *'
 shortsize='2'
 shrpenv=''
-sig_count='64'
-sig_name='ZERO HUP INT QUIT ILL TRAP ABRT BUS FPE KILL USR1 SEGV USR2 PIPE ALRM TERM STKFLT CHLD CONT STOP TSTP TTIN TTOU URG XCPU XFSZ VTALRM PROF WINCH IO PWR SYS NUM32 NUM33 NUM34 RTMIN NUM36 NUM37 NUM38 NUM39 NUM40 NUM41 NUM42 NUM43 NUM44 NUM45 NUM46 NUM47 NUM48 NUM49 NUM50 NUM51 NUM52 NUM53 NUM54 NUM55 NUM56 NUM57 NUM58 NUM59 NUM60 NUM61 NUM62 NUM63 IOT CLD POLL UNUSED '
-sig_name_init='"ZERO", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "BUS", "FPE", "KILL", "USR1", "SEGV", "USR2", "PIPE", "ALRM", "TERM", "STKFLT", "CHLD", "CONT", "STOP", "TSTP", "TTIN", "TTOU", "URG", "XCPU", "XFSZ", "VTALRM", "PROF", "WINCH", "IO", "PWR", "SYS", "NUM32", "NUM33", "NUM34", "RTMIN", "NUM36", "NUM37", "NUM38", "NUM39", "NUM40", "NUM41", "NUM42", "NUM43", "NUM44", "NUM45", "NUM46", "NUM47", "NUM48", "NUM49", "NUM50", "NUM51", "NUM52", "NUM53", "NUM54", "NUM55", "NUM56", "NUM57", "NUM58", "NUM59", "NUM60", "NUM61", "NUM62", "NUM63", "IOT", "CLD", "POLL", "UNUSED", 0'
-sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 6 17 29 31 '
-sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 6, 17, 29, 31, 0'
-sig_size='68'
+sig_count='65'
+sig_name='ZERO HUP INT QUIT ILL TRAP ABRT BUS FPE KILL USR1 SEGV USR2 PIPE ALRM TERM STKFLT CHLD CONT STOP TSTP TTIN TTOU URG XCPU XFSZ VTALRM PROF WINCH IO PWR SYS NUM32 NUM33 NUM34 RTMIN NUM36 NUM37 NUM38 NUM39 NUM40 NUM41 NUM42 NUM43 NUM44 NUM45 NUM46 NUM47 NUM48 NUM49 NUM50 NUM51 NUM52 NUM53 NUM54 NUM55 NUM56 NUM57 NUM58 NUM59 NUM60 NUM61 NUM62 NUM63 RTMAX IOT CLD POLL UNUSED '
+sig_name_init='"ZERO", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "BUS", "FPE", "KILL", "USR1", "SEGV", "USR2", "PIPE", "ALRM", "TERM", "STKFLT", "CHLD", "CONT", "STOP", "TSTP", "TTIN", "TTOU", "URG", "XCPU", "XFSZ", "VTALRM", "PROF", "WINCH", "IO", "PWR", "SYS", "NUM32", "NUM33", "NUM34", "RTMIN", "NUM36", "NUM37", "NUM38", "NUM39", "NUM40", "NUM41", "NUM42", "NUM43", "NUM44", "NUM45", "NUM46", "NUM47", "NUM48", "NUM49", "NUM50", "NUM51", "NUM52", "NUM53", "NUM54", "NUM55", "NUM56", "NUM57", "NUM58", "NUM59", "NUM60", "NUM61", "NUM62", "NUM63", "RTMAX", "IOT", "CLD", "POLL", "UNUSED", 0'
+sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 6 17 29 31 '
+sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 6, 17, 29, 31, 0'
+sig_size='69'
 signal_t='void'
-sitearch='/usr/lib/perl5/site_perl/5.8.4/i486-linux'
-sitearchexp='/usr/lib/perl5/site_perl/5.8.4/i486-linux'
+sitearch='/usr/lib/perl5/site_perl/5.8.6/i486-linux'
+sitearchexp='/usr/lib/perl5/site_perl/5.8.6/i486-linux'
 sitebin='/usr/bin'
 sitebinexp='/usr/bin'
 sitehtml1dir=''
 sitehtml1direxp=''
 sitehtml3dir=''
 sitehtml3direxp=''
-sitelib='/usr/lib/perl5/site_perl/5.8.4'
+sitelib='/usr/lib/perl5/site_perl/5.8.6'
 sitelib_stem='/usr/lib/perl5/site_perl'
-sitelibexp='/usr/lib/perl5/site_perl/5.8.4'
+sitelibexp='/usr/lib/perl5/site_perl/5.8.6'
 siteman1dir='/usr/share/man/man1'
 siteman1direxp='/usr/share/man/man1'
 siteman3dir='/usr/share/man/man3'
@@ -1016,7 +1021,7 @@ stdio_stream_array=''
 strerror_r_proto='0'
 strings='/usr/include/string.h'
 submit=''
-subversion='4'
+subversion='6'
 sysman='/usr/share/man/man1'
 tail=''
 tar=''
@@ -1099,8 +1104,8 @@ vendorprefix=''
 vendorprefixexp=''
 vendorscript=''
 vendorscriptexp=''
-version='5.8.4'
-version_patchlevel_string='version 8 subversion 4'
+version='5.8.6'
+version_patchlevel_string='version 8 subversion 6'
 versiononly='undef'
 vi=''
 voidflags='15'
@@ -1110,6 +1115,8 @@ yaccflags=''
 zcat=''
 zip='zip'
 !END!
+s/(byteorder=)(['"]).*?\2/$1$2$byteorder$2/m;
+our $Config_SH : unique = $_;
 
 # Search for it in the big string 
 sub fetch_string {
@@ -1242,18 +1249,27 @@ sub config_sh {
 
 sub config_re {
     my $re = shift;
-    return map { chomp; $_ } grep /^$re=/, split /^/, $Config_SH;
+    return map { chomp; $_ } grep eval{ /^(?:$re)=/ }, split /^/, $Config_SH;
 }
 
 sub config_vars {
+    # implements -V:cfgvar option (see perlrun -V:)
     foreach (@_) {
-	if (/\W/) {
-	    my @matches = config_re($_);
-	    print map "$_\n", @matches ? @matches : "$_: not found";
+	# find optional leading, trailing colons; and query-spec
+	my ($notag,$qry,$lncont) = m/^(:)?(.*?)(:)?$/;	# flags fore and aft, 
+	# map colon-flags to print decorations
+	my $prfx = $notag ? '': "$qry=";		# tag-prefix for print
+	my $lnend = $lncont ? ' ' : ";\n";		# line ending for print
+
+	# all config-vars are by definition \w only, any \W means regex
+	if ($qry =~ /\W/) {
+	    my @matches = config_re($qry);
+	    print map "$_$lnend", @matches ? @matches : "$qry: not found"		if !$notag;
+	    print map { s/\w+=//; "$_$lnend" } @matches ? @matches : "$qry: not found"	if  $notag;
 	} else {
-	    my $v = (exists $Config{$_}) ? $Config{$_} : 'UNKNOWN';
+	    my $v = (exists $Config{$qry}) ? $Config{$qry} : 'UNKNOWN';
 	    $v = 'undef' unless defined $v;
-	    print "$_='$v';\n";
+	    print "${prfx}'${v}'$lnend";
 	}
     }
 }
@@ -1265,34 +1281,28 @@ sub TIEHASH {
 # avoid Config..Exporter..UNIVERSAL search for DESTROY then AUTOLOAD
 sub DESTROY { }
 
-my $i = 0;
-foreach my $c (4,3,2) { $i |= ord($c); $i <<= 8 }
-$i |= ord(1);
-my $value = join('', unpack('aaaa', pack('L!', $i)));
-
-
 tie %Config, 'Config', {
-    'archlibexp' => '/usr/lib/perl5/5.8.4/i486-linux',
+    'archlibexp' => '/usr/lib/perl5/5.8.6/i486-linux',
     'archname' => 'i486-linux',
     'cc' => 'cc',
-    'ccflags' => '-fno-strict-aliasing -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64',
-    'cppflags' => '-fno-strict-aliasing -I/usr/local/include',
+    'ccflags' => '-fno-strict-aliasing -pipe -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64',
+    'cppflags' => '-fno-strict-aliasing -pipe -I/usr/local/include',
     'dlsrc' => 'dl_dlopen.xs',
     'dynamic_ext' => 'B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared',
-    'installarchlib' => '/usr/lib/perl5/5.8.4/i486-linux',
-    'installprivlib' => '/usr/lib/perl5/5.8.4',
+    'installarchlib' => '/usr/lib/perl5/5.8.6/i486-linux',
+    'installprivlib' => '/usr/lib/perl5/5.8.6',
     'libpth' => '/usr/local/lib /lib /usr/lib',
     'libs' => '-lnsl -lgdbm -ldb -ldl -lm -lcrypt -lutil -lc',
     'osname' => 'linux',
-    'osvers' => '2.4.26',
+    'osvers' => '2.4.28',
     'prefix' => '/usr',
-    'privlibexp' => '/usr/lib/perl5/5.8.4',
+    'privlibexp' => '/usr/lib/perl5/5.8.6',
     'sharpbang' => '#!',
     'shsharp' => 'true',
     'so' => 'so',
     'startsh' => '#!/bin/sh',
     'static_ext' => ' ',
-    byteorder => $value,
+    byteorder => $byteorder,
 
 };
 
